#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-C7uZX6ey5U1KllzcdhL4Y8
key:                  monad-par-extras-0.3.3-C7uZX6ey5U1KllzcdhL4Y8
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  05b01f8f32a894436c4cffd72b22c9ef
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-8.10.5/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/monad-par-extras-0.3.3
hs-libraries:         HSmonad-par-extras-0.3.3-C7uZX6ey5U1KllzcdhL4Y8
depends:
    abstract-par-0.3.3-B1XLKeQcwYwJeOMyLVofnm base-4.14.2.0
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl deepseq-1.4.4.0 mtl-2.2.2
    random-1.2.0-GZbCBA9NAlUBaVRSIi1HYu transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

